@@ -152,20 +152,6 @@ application_exe() {
 	printf '%s' "$application_exe"
 }
 
-# Print the path to the application binary, with single quotes escaped,
-# for inclusion in a single quote delimited variable declaration.
-# USAGE: application_exe_escaped $application
-application_exe_escaped() {
-	local application
-	application="$1"
-
-	local application_exe
-	application_exe=$(application_exe "$application")
-
-	# If the file name includes single quotes, replace each one with: '\''
-	printf '%s' "$application_exe" | sed "s/'/'\\\''/g"
-}
-
 # Print the full path to the application binary
 # An error is thrown if the binary file could not be found anywhere
 # USAGE: application_exe_path $application_exe
