@@ -112,7 +112,7 @@ dosbox_exec_line() {
 	application="$1"
 
 	local application_exe application_options
-	application_exe=$(application_exe_escaped "$application")
+	application_exe=$(application_exe "$application")
 	application_options=$(application_options "$application")
 	cat <<- EOF
 	$application_exe $application_options \$@
