@@ -85,7 +85,7 @@ java_exec_line() {
 
 	local application_java_options application_exe application_options
 	application_java_options=$(application_java_options "$application")
-	application_exe=$(application_exe_escaped "$application")
+	application_exe=$(application_exe "$application")
 	application_options=$(application_options "$application")
 	cat <<- EOF
 	java $application_java_options -jar "${application_exe}" $application_options "\$@"
