@@ -3,7 +3,7 @@
 # RETURN: the list of tweaks, one per line
 wine_wineprefix_tweaks() {
 	local tweaks_list
-	tweaks_list=${WINE_WINEPREFIX_TWEAKS:-}
+	tweaks_list=$(context_value 'WINE_WINEPREFIX_TWEAKS')
 
 	printf '%s' "$tweaks_list" | list_clean
 }
