@@ -42,7 +42,8 @@ unity3d_application_exe_default() {
 			continue
 		fi
 		## Do not throw an error if no path is found for the current candidate.
-		filename_path=$(application_exe_path "$filename_candidate") 2>/dev/null || true
+		## The output redirection must be done inside the subshell, or bash --posix will ignore it.
+		filename_path=$(application_exe_path "$filename_candidate" 2>/dev/null || true)
 		if [ -n "$filename_path" ]; then
 			filename_found="$filename_candidate"
 			break
