@@ -60,43 +60,44 @@ launcher_unity3d_force_locale() {
 
 # Disable the MAP_32BIT flag to prevent a crash one some Linux versions when running a 64-bit build of Unity3D
 # USAGE: unity3d_disable_map32bit
-# RETURN: the code snippet, a multi-lines string, indented with four spaces
 unity3d_disable_map32bit() {
-	local hacks_list
-	hacks_list=$(hacks_list)
-	export PRELOAD_HACKS_LIST="$hacks_list
-HACK_UNITY3D_DISABLE_MAP32BIT"
+	local unity3d_version
+	unity3d_version=$(unity3d_version)
+	case "$unity3d_version" in
+		('4.'*|'5.'*)
+			local package package_architecture
+			package=$(current_package)
+			package_architecture=$(package_architecture "$package")
+			if [ "$package_architecture" = '32' ]; then
+				# This Unity3D build is not affected by the MAP_32BIT flag.
+				return 0
+			fi
+		;;
+		(*)
+			# This Unity3D build is not affected by the MAP_32BIT flag.
+			return 0
+		;;
+	esac
+	cat <<- 'EOF'
+	#define _GNU_SOURCE
+	#include <stdlib.h>
+	#include <dlfcn.h>
+	#include <sys/mman.h>
 
-	local package
-	package=$(current_package)
+	typedef void *(*orig_mmap_type)(void *addr, size_t length, int prot,
+	                                int flags, int fd, off_t offset);
 
-	export HACK_UNITY3D_DISABLE_MAP32BIT_NAME='disable-map32bit'
-	export HACK_UNITY3D_DISABLE_MAP32BIT_PACKAGE="$package"
-	export HACK_UNITY3D_DISABLE_MAP32BIT_DESCRIPTION='LD_PRELOAD shim disabling the MAP_32BIT flag
-This prevents crashes on some Linux versions when running a 64-bit build of Unity3D.'
-	export HACK_UNITY3D_DISABLE_MAP32BIT_SOURCE='
-#define _GNU_SOURCE
-#include <stdlib.h>
-#include <dlfcn.h>
-#include <sys/mman.h>
+	void *mmap(void *addr, size_t length, int prot, int flags,
+	           int fd, off_t offset)
+	{
+	    static orig_mmap_type orig_mmap = NULL;
+	    if (orig_mmap == NULL)
+	        orig_mmap = (orig_mmap_type)dlsym(RTLD_NEXT, "mmap");
 
-typedef void *(*orig_mmap_type)(void *addr, size_t length, int prot,
-                                int flags, int fd, off_t offset);
+	    flags &= ~MAP_32BIT;
 
-void *mmap(void *addr, size_t length, int prot, int flags,
-           int fd, off_t offset)
-{
-    static orig_mmap_type orig_mmap = NULL;
-    if (orig_mmap == NULL)
-        orig_mmap = (orig_mmap_type)dlsym(RTLD_NEXT, "mmap");
-
-    flags &= ~MAP_32BIT;
-
-    return orig_mmap(addr, length, prot, flags, fd, offset);
-}
-'
-
-	hack_build 'HACK_UNITY3D_DISABLE_MAP32BIT'
-	hack_inclusion 'HACK_UNITY3D_DISABLE_MAP32BIT'
+	    return orig_mmap(addr, length, prot, flags, fd, offset);
+	}
+	EOF
 }
 
