@@ -80,6 +80,10 @@ archlinux_dependencies_single_command() {
 			package_names='
 			openmw'
 		;;
+		('pidwait')
+			package_names='
+			procps-ng'
+		;;
 		('pulseaudio')
 			package_names='
 			pulseaudio'
