@@ -370,6 +370,13 @@ dependency_package_providing_library_arch() {
 		('libpulse-simple.so.0')
 			package_name='libpulse'
 		;;
+		( \
+			'libQt5Core.so.5' | \
+			'libQt5Gui.so.5' | \
+			'libQt5Widgets.so.5' \
+		)
+			package_name='qt5-base'
+		;;
 		('libresolv.so.2')
 			package_name='glibc'
 		;;
@@ -941,6 +948,14 @@ dependency_package_providing_library_arch32() {
 		('libpulse-simple.so.0')
 			package_name='lib32-libpulse'
 		;;
+		( \
+			'libQt5Core.so.5' | \
+			'libQt5Gui.so.5' | \
+			'libQt5Widgets.so.5' \
+		)
+			# These libraries are not provided in 32-bit builds for Arch Linux.
+			unset package_name
+		;;
 		('libresolv.so.2')
 			package_name='lib32-glibc'
 		;;
