@@ -360,6 +360,15 @@ dependency_package_providing_library_deb() {
 		('libpulse-simple.so.0')
 			package_name='libpulse0'
 		;;
+		( \
+			'libQt5Core.so.5' | \
+			'libQt5Gui.so.5' \
+		)
+			package_name='libqt5core5'
+		;;
+		('libQt5Widgets.so.5')
+			package_name='libqt5widgets5'
+		;;
 		('libresolv.so.2')
 			package_name='libc6'
 		;;
